<?php

switch ($messaggio) {

case "Il cognome verrà cambiato da":  		$messaggio = "El cognom canviarà de"; break;
case "a":  					$messaggio = "a"; break;
case "Il nome verrà cambiato da":  		$messaggio = "El nom canviarà de"; break;
case "Il sesso verrà cambiato a":  		$messaggio = "El gènere canviarà a"; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "La data de neixament canviarà de"; break;
case "Il telefono verrà cambiato da":  		$messaggio = "El telèfon canviarà de"; break;
case "La via  verrà cambiata da":  		$messaggio = "El carrer canviarà de"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "El número del carrer canviarà de"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "La ciutat de residència canviarà de"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "El país de rèsidencia canviarà de"; break;
case "Il CAP verrà cambiato da":  		$messaggio = "El codi postal canviarà de"; break;
case "Il fax verrà cambiato da":  		$messaggio = "El fax canviarà de"; break;
case "L' email verrà cambiata da":  		$messaggio = "L'email canviarà de"; break;
case "Il 2° telefono verrà cambiato da":  	$messaggio = "El segon telèfon canviarà de"; break;
case "Il 3° telefono verrà cambiato da":  	$messaggio = "El tercer telèfòn canviarà de"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "El <b>comentari</b> canviarà"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = "El <b>nom</b> serà esborrat"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = "La <b>data de neixament</b> serà esborrada"; break;
case "Il <b>telefono</b> verrà cancellato":  	$messaggio = "El <b>telèfon</b> serà esborrat"; break;
case "La <b>via</b> verrà cancellata":  	$messaggio = "El <b>carrer</b> serà esborrat"; break;
case "Il <b>n° civico</b> verrà cancellato":  	$messaggio = "El <b>número del carrer</b> serà esborrat"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = "La <b>ciutat de residència</b> serà esborrada"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = "El <b>país de residència</b> serà esborrat"; break;
case "Il <b>CAP</b> verrà cancellato":  	$messaggio = "El <b>codi postal</b> serà esborrat"; break;
case "Il <b>fax</b> verrà cancellato":  	$messaggio = "El <b>fax</b> serà esborrat"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "L'<b>email</b> serà esborrat"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "El <b>segon telèfon</b> serà esborrat"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "El <b>tercer telèfon</b> serà esborrat"; break;
case "Continua":  				$messaggio = "Continua"; break;
case "Il cliente":  				$messaggio = "El client"; break;
case "è stato modificato":  			$messaggio = "ha estat modificat"; break;
case "Torna indietro":  			$messaggio = "Torna enrere"; break;
case "Modifica i dati del cliente":  		$messaggio = "Modifica les dades del client"; break;
case "Cognome":  				$messaggio = "Cognoms"; break;
case "cambia in":  				$messaggio = "canvia a"; break;
case "Nome":  					$messaggio = "Nom"; break;
case "cancella":  				$messaggio = "esborra"; break;
case "Sesso":  					$messaggio = "Gènere"; break;
case "Data di nascita":  			$messaggio = "Data de neixament"; break;
case "Telefono":  				$messaggio = "Telèfon"; break;
case "Via":  					$messaggio = "Carrer"; break;
case "Piazza":  				$messaggio = "Plaça"; break;
case "Viale":  					$messaggio = "Avinguda"; break;
case "Piazzale":  				$messaggio = "Paseig"; break;
case "Vicolo":  				$messaggio = "Bulevar"; break;
case "Numero civico":  				$messaggio = "Número"; break;
case "Città di residenza":  			$messaggio = "Ciutat de residència"; break;
case "Nazione di residenza":  			$messaggio = "País de residència"; break;
case "CAP":  					$messaggio = "Códi postal"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "2° telefono":  				$messaggio = "Segon telèfon"; break;
case "3° telefono":  				$messaggio = "Tercer telèfon"; break;
case "Commento":  				$messaggio = "Comentari"; break;
case "documento di tipo":  			$messaggio = "document tipus"; break;
case "visualizza":  				$messaggio = "veure"; break;
case "visualizza il documento":  		$messaggio = "veure el document"; break;
case "Prenotazioni del cliente":  		$messaggio = "Reserves del client"; break;
case "nel":  					$messaggio = "al"; break;
case "Cognome_del_cliente":  			$messaggio = "Cognom_del_client"; break;
case "Data_iniziale":  				$messaggio = "Data_arribada"; break;
case "Data_finale":  				$messaggio = "Data_sortida"; break;
case "Tariffa_completa":  			$messaggio = "Preu_final"; break;
case "Caparra":  				$messaggio = "Paga_i_senyal"; break;
case "Pagato":  				$messaggio = "Pagat"; break;
case "Commento":  				$messaggio = "Comentari"; break;
case "Pers":  					$messaggio = "Pers"; break;
case "Inserito da":  				$messaggio = "Inserit per"; break;
case "Si considererà l'utente":  		$messaggio = "L'usuari"; break;
case "come colui che ha inserito il cliente":	$messaggio = "serà enregistrat com a inseridor del client"; break;
case "Cliente cancellato":  			$messaggio = "Cliente esborrat"; break;
case "Cancella il cliente":  			$messaggio = "Esborra el client"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "Aquest client no pot ésser esborrat perquè te reserves associades"; break;
case "NO":  					$messaggio = "NO"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "Segur que cal <div style=\"display: inline; color: red;\">esborrar</div> el client"; break;
case "SI":  					$messaggio = "SÍ"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Província de residència"; break;
case "Scadenza documento":  			$messaggio = "Caducitat document"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "La província de residència canviarà de"; break;
case "Il documento verrà cambiato da":  	$messaggio = "El document canviarà de"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "La data de caducitat del document canviarà de"; break;
case "La <b>regione di residenza</b> verrà cancellata":  	$messaggio = "La <b>província de residència</b> serà esborrada"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "El <b>document</b> serà esborrat"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = "La <b>data de caducitat del document</b> serà esborrada"; break;
case "Cittadinanza":  				$messaggio = "Nacionalitat"; break;
case "Nazione di nascita":  			$messaggio = "País de neixament"; break;
case "Reg./Prov. di nascita":  			$messaggio = "Província de neixament"; break;
case "Città di nascita":  			$messaggio = "Ciutat de neixament"; break;
case "Città di rilascio":  			$messaggio = "Ciutat d'emissió"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Província d'emissió"; break;
case "Nazione di rilascio":  			$messaggio = "País emissor"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "La nacionalitat canviarà de"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "El país de neixament canviarà de"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "La província de neixament canviarà de"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "La ciutat de neixament canviarà de"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "La ciutat d'emissió del document canviarà de"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "La província d'emissió del document canviarà de"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "El país emissor del document canviarà de"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = "La <b>nacionalitat</b> serà esborrada"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "La <b>data de neixament</b> serà esborrada"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "La <b>província de neixament</b> serà esborrada"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "La <b>ciutat de neixament</b> serà esborrada"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "La <b>província d'emissió del document</b> serà esborrada"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "La <b>ciutat d'emissió del document</b> serà esborrada"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "El <b>país emissor del document</b> serà esborrat"; break;
case "Codice fiscale":  			$messaggio = "NIF/CIF"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "El NIF/CIF canviarà de"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "El <b>NIF/CIF</b> serà esborrat"; break;
case "Titolo":  				$messaggio = "Títol"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "El títol canviarà de"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "El <b>títol</b> serà esborrat"; break;
case "Partita iva":  				$messaggio = "N. identificació fiscal"; break;
case "La partita iva verrà cambiata da":  	$messaggio = "El n. d'identificació fiscal canviarà de"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = "El <b>n. d'identificació fiscal</b> serà esborrat"; break;
case "data inserimento":  			$messaggio = "data d'inserció"; break;
case "carte di credito":  			$messaggio = "targetes bancàries"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "contrasenya per mostrar les targetes bancàries"; break;
case "invia":  					$messaggio = "enviar"; break;
case "password errata":  			$messaggio = "contrasenya errònia"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "les dades de la targeta han estat esborrades"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "el número de la targeta bancària és <span class=\"colred\">erroni</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "el número de CVC és <span class=\"colred\">erroni</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "les dades de la targeta han estat inserides"; break;
case "carta di credito del cliente":  		$messaggio = "targeta bancària del cliente"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "modifica i dati della carta di credito":	$messaggio = "modificar les dades de la targeta"; break;
case "cancella questa carta di credito":  	$messaggio = "esborrar aquesta targeta"; break;
case "soprannome":  				$messaggio = "sobrenom"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "El sobrenom canviarà de"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "El <b>sobrenom</b> serà esborrat"; break;
case "Lingua":  				$messaggio = "Idioma"; break;
case "La lingua verrà cambiata da":  		$messaggio = "L'idioma canviarà de"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "L'<b>idioma</b> serà esborrat"; break;
case "Modifica Cliente":  			$messaggio = "Modify Client"; break;
case "Email":  					$messaggio = "Email"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Documento":  				$messaggio = "Document"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Numero":  				$messaggio = "Number"; break;
case "Titolare":  				$messaggio = "Holder"; break;
case "Scadenza":  				$messaggio = "Expiration"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Credit card data can be viewed only on a secure connection"; break;
case "Il campo":  				$messaggio = "The field"; break;
case "verrà tolto":  				$messaggio = "will be deleted"; break;
case "verrà modificato":  			$messaggio = "will be modified"; break;
case "verrà aggiunto":  			$messaggio = "will be added"; break;
case "scaduta":  				$messaggio = "expired"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "You'll be able to view credit cards again after changing the password"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "You'll be able to view credit cards again after the administrator user changes the password"; break;
case "Login temporaneamente bloccato":  	$messaggio = "Login temporarily locked"; break;
case "NOTA":  					$messaggio = "NOTICE"; break;
case "questo valore è gia stato cancellato, questa è l'ultima volta che viene visualizzato":	$messaggio = "this value has already been deleted, this is the last time you'll see it"; break;
case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "You'll be able to see this value only one more time"; break;
case "Cancellalo ora":  			$messaggio = "Delete it now"; break;
case "CVC cancellato":  			$messaggio = "CVC deleted"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
case "La seconda email verrà cambiata da":  	$messaggio = "The second email will be changed from"; break;
case "L'email certificata (PEC) o il codice destinatario verrà cambiato da":	$messaggio = "The certified email will be changed from"; break;
case "La <b>seconda email</b> verrà cancellata":	$messaggio = "The <b>second email</b> will be deleted"; break;
case "L'<b>email certificata (PEC) o il codice destinatario</b> verrà cancellato":	$messaggio = "The <b>certified email</b> will be deleted"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "Il 2° cognome verrà cambiato da":  	$messaggio = "The 2nd surname will be changed from"; break;
case "Il <b>2° cognome</b> verrà cancellato":	$messaggio = "The <b>2nd surname</b> will be deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
